==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/geoip/lang/zh-cn.js <==
﻿/*
 * PLUGIN GEOIP
 *
 * Chinese Simplified language file.
 *
 * Initial Author: art.spb, December 2009.
 *
 * Author: 
 */

 theUILang.peerComment		= "添加注释";
 theUILang.peerCommentLabel	= "为这个 peer 添加新注释";
 theUILang.commentName		= "注释";
 theUILang.countryName		= "国家";

 theUILang.country = new Array();
 theUILang.country[ "ad" ] = "安道尔";
 theUILang.country[ "ae" ] = "阿拉伯联合酋长国";
 theUILang.country[ "af" ] = "阿富汗";
 theUILang.country[ "ag" ] = "安提瓜和巴布达";
 theUILang.country[ "ai" ] = "安圭拉";
 theUILang.country[ "al" ] = "阿尔巴尼亚";
 theUILang.country[ "am" ] = "亚美尼亚";
 theUILang.country[ "ao" ] = "安哥拉";
 theUILang.country[ "aq" ] = "南极";
 theUILang.country[ "ar" ] = "阿根廷";
 theUILang.country[ "as" ] = "美属萨摩亚";
 theUILang.country[ "at" ] = "奥地利";
 theUILang.country[ "au" ] = "澳大利亚";
 theUILang.country[ "aw" ] = "阿鲁巴";
 theUILang.country[ "ax" ] = "奥兰群岛";
 theUILang.country[ "az" ] = "阿塞拜疆";
 theUILang.country[ "ba" ] = "波斯尼亚和黑塞哥维那";
 theUILang.country[ "bb" ] = "巴巴多斯";
 theUILang.country[ "bd" ] = "孟加拉国";
 theUILang.country[ "be" ] = "比利时";
 theUILang.country[ "bf" ] = "布基纳法索";
 theUILang.country[ "bg" ] = "保加利亚";
 theUILang.country[ "bh" ] = "巴林";
 theUILang.country[ "bi" ] = "布隆迪";
 theUILang.country[ "bj" ] = "贝宁";
 theUILang.country[ "bl" ] = "圣巴泰勒米";
 theUILang.country[ "bm" ] = "百慕大";
 theUILang.country[ "bn" ] = "文莱";
 theUILang.country[ "bo" ] = "玻利维亚";
 theUILang.country[ "bq" ] = "博内尔";
 theUILang.country[ "br" ] = "巴西";
 theUILang.country[ "bs" ] = "巴哈马";
 theUILang.country[ "bt" ] = "不丹";
 theUILang.country[ "bv" ] = "布维岛";
 theUILang.country[ "bw" ] = "博茨瓦纳";
 theUILang.country[ "by" ] = "白俄罗斯";
 theUILang.country[ "bz" ] = "伯利兹";
 theUILang.country[ "ca" ] = "加拿大";
 theUILang.country[ "cc" ] = "科科斯群岛";
 theUILang.country[ "cd" ] = "刚果（金）";
 theUILang.country[ "cf" ] = "中非共和国";
 theUILang.country[ "cg" ] = "刚果（布拉柴维尔）";
 theUILang.country[ "ch" ] = "瑞士";
 theUILang.country[ "ci" ] = "科特迪瓦";
 theUILang.country[ "ck" ] = "库克群岛";
 theUILang.country[ "cl" ] = "智利";
 theUILang.country[ "cm" ] = "喀麦隆";
 theUILang.country[ "cn" ] = "中国";
 theUILang.country[ "co" ] = "哥伦比亚";
 theUILang.country[ "cr" ] = "哥斯达黎加";
 theUILang.country[ "cu" ] = "古巴";
 theUILang.country[ "cv" ] = "佛得角";
 theUILang.country[ "cw" ] = "库拉索";
 theUILang.country[ "cx" ] = "圣诞岛";
 theUILang.country[ "cy" ] = "塞浦路斯";
 theUILang.country[ "cz" ] = "捷克共和国";
 theUILang.country[ "de" ] = "德国";
 theUILang.country[ "dj" ] = "吉布提";
 theUILang.country[ "dk" ] = "丹麦";
 theUILang.country[ "dm" ] = "多米尼克";
 theUILang.country[ "do" ] = "多米尼加共和国";
 theUILang.country[ "dz" ] = "阿尔及利亚";
 theUILang.country[ "ec" ] = "厄瓜多尔";
 theUILang.country[ "ee" ] = "爱沙尼亚";
 theUILang.country[ "eg" ] = "埃及";
 theUILang.country[ "eh" ] = "西撒哈拉";
 theUILang.country[ "er" ] = "厄立特里亚";
 theUILang.country[ "es" ] = "西班牙";
 theUILang.country[ "et" ] = "埃塞俄比亚";
 theUILang.country[ "eu" ] = "欧洲联盟";
 theUILang.country[ "fi" ] = "芬兰";
 theUILang.country[ "fj" ] = "斐济";
 theUILang.country[ "fk" ] = "福克兰群岛";
 theUILang.country[ "fm" ] = "密克罗尼西亚";
 theUILang.country[ "fo" ] = "法罗群岛";
 theUILang.country[ "fr" ] = "法国";
 theUILang.country[ "ga" ] = "加蓬";
 theUILang.country[ "gb" ] = "英国";
 theUILang.country[ "gd" ] = "格林纳达";
 theUILang.country[ "ge" ] = "格鲁吉亚";
 theUILang.country[ "gf" ] = "法属圭亚那";
 theUILang.country[ "gg" ] = "根西岛";
 theUILang.country[ "gh" ] = "加纳";
 theUILang.country[ "gi" ] = "直布罗陀";
 theUILang.country[ "gl" ] = "格陵兰";
 theUILang.country[ "gm" ] = "冈比亚";
 theUILang.country[ "gn" ] = "几内亚";
 theUILang.country[ "gp" ] = "瓜德罗普岛";
 theUILang.country[ "gq" ] = "赤道几内亚";
 theUILang.country[ "gr" ] = "希腊";
 theUILang.country[ "gs" ] = "南乔治亚岛和南桑威奇群岛";
 theUILang.country[ "gt" ] = "危地马拉";
 theUILang.country[ "gu" ] = "关岛";
 theUILang.country[ "gw" ] = "几内亚比绍";
 theUILang.country[ "gy" ] = "圭亚那";
 theUILang.country[ "hk" ] = "香港";
 theUILang.country[ "hm" ] = "赫德岛和麦当劳群岛";
 theUILang.country[ "hn" ] = "洪都拉斯";
 theUILang.country[ "hr" ] = "克罗地亚";
 theUILang.country[ "ht" ] = "海地";
 theUILang.country[ "hu" ] = "匈牙利";
 theUILang.country[ "id" ] = "印尼";
 theUILang.country[ "ie" ] = "爱尔兰";
 theUILang.country[ "il" ] = "以色列";
 theUILang.country[ "im" ] = "马恩岛";
 theUILang.country[ "in" ] = "印度";
 theUILang.country[ "io" ] = "英属印度洋领地";
 theUILang.country[ "iq" ] = "伊拉克";
 theUILang.country[ "ir" ] = "伊朗";
 theUILang.country[ "is" ] = "冰岛";
 theUILang.country[ "it" ] = "意大利";
 theUILang.country[ "je" ] = "新泽西";
 theUILang.country[ "jm" ] = "牙买加";
 theUILang.country[ "jo" ] = "乔丹";
 theUILang.country[ "jp" ] = "日本";
 theUILang.country[ "ke" ] = "肯尼亚";
 theUILang.country[ "kg" ] = "吉尔吉斯斯坦";
 theUILang.country[ "kh" ] = "柬埔寨";
 theUILang.country[ "ki" ] = "基里巴斯";
 theUILang.country[ "km" ] = "科摩罗";
 theUILang.country[ "kn" ] = "圣基茨和尼维斯";
 theUILang.country[ "kp" ] = "北朝鲜";
 theUILang.country[ "kr" ] = "南朝鲜";
 theUILang.country[ "kw" ] = "科威特";
 theUILang.country[ "ky" ] = "开曼群岛";
 theUILang.country[ "kz" ] = "哈萨克斯坦";
 theUILang.country[ "la" ] = "老挝";
 theUILang.country[ "lb" ] = "黎巴嫩";
 theUILang.country[ "lc" ] = "圣卢西亚";
 theUILang.country[ "li" ] = "列支敦士登";
 theUILang.country[ "lk" ] = "斯里兰卡";
 theUILang.country[ "lr" ] = "利比里亚";
 theUILang.country[ "ls" ] = "莱索托";
 theUILang.country[ "lt" ] = "立陶宛";
 theUILang.country[ "lu" ] = "卢森堡";
 theUILang.country[ "lv" ] = "拉脱维亚";
 theUILang.country[ "ly" ] = "利比亚";
 theUILang.country[ "ma" ] = "摩洛哥";
 theUILang.country[ "mc" ] = "摩纳哥";
 theUILang.country[ "md" ] = "摩尔多瓦";
 theUILang.country[ "me" ] = "黑山";
 theUILang.country[ "mf" ] = "圣马丁";
 theUILang.country[ "mg" ] = "马达加斯加";
 theUILang.country[ "mh" ] = "马绍尔群岛";
 theUILang.country[ "mk" ] = "北马其顿";
 theUILang.country[ "ml" ] = "玛丽";
 theUILang.country[ "mm" ] = "缅甸";
 theUILang.country[ "mn" ] = "蒙";
 theUILang.country[ "mo" ] = "澳门";
 theUILang.country[ "mp" ] = "北马里亚纳群岛";
 theUILang.country[ "mq" ] = "马提尼克岛";
 theUILang.country[ "mr" ] = "毛里塔尼亚";
 theUILang.country[ "ms" ] = "蒙特塞拉特";
 theUILang.country[ "mt" ] = "马耳他";
 theUILang.country[ "mu" ] = "毛里求斯";
 theUILang.country[ "mv" ] = "马尔代夫";
 theUILang.country[ "mw" ] = "马拉维";
 theUILang.country[ "mx" ] = "墨西哥";
 theUILang.country[ "my" ] = "马来西亚";
 theUILang.country[ "mz" ] = "莫桑比克";
 theUILang.country[ "na" ] = "纳米比亚";
 theUILang.country[ "nc" ] = "新喀里多尼亚";
 theUILang.country[ "ne" ] = "尼日尔";
 theUILang.country[ "nf" ] = "诺福克岛";
 theUILang.country[ "ng" ] = "尼日利亚";
 theUILang.country[ "ni" ] = "尼加拉瓜";
 theUILang.country[ "nl" ] = "荷兰";
 theUILang.country[ "no" ] = "挪威";
 theUILang.country[ "np" ] = "尼泊尔";
 theUILang.country[ "nr" ] = "瑙鲁";
 theUILang.country[ "nu" ] = "纽埃";
 theUILang.country[ "nz" ] = "新西兰";
 theUILang.country[ "om" ] = "阿曼";
 theUILang.country[ "pa" ] = "巴拿马";
 theUILang.country[ "pe" ] = "秘鲁";
 theUILang.country[ "pf" ] = "法属波利尼西亚的";
 theUILang.country[ "pg" ] = "巴布亚新几内亚";
 theUILang.country[ "ph" ] = "菲律宾";
 theUILang.country[ "pk" ] = "巴基斯坦";
 theUILang.country[ "pl" ] = "波兰";
 theUILang.country[ "pm" ] = "圣皮埃尔和密克隆";
 theUILang.country[ "pn" ] = "皮特凯恩";
 theUILang.country[ "pr" ] = "波多黎各";
 theUILang.country[ "ps" ] = "巴勒斯坦";
 theUILang.country[ "pt" ] = "葡萄牙";
 theUILang.country[ "pw" ] = "帕劳";
 theUILang.country[ "py" ] = "巴拉圭";
 theUILang.country[ "qa" ] = "卡塔尔";
 theUILang.country[ "re" ] = "团圆";
 theUILang.country[ "ro" ] = "罗马尼亚";
 theUILang.country[ "rs" ] = "塞尔维亚";
 theUILang.country[ "ru" ] = "俄罗斯";
 theUILang.country[ "rw" ] = "卢旺达";
 theUILang.country[ "sa" ] = "沙特阿拉伯";
 theUILang.country[ "sb" ] = "所罗门群岛";
 theUILang.country[ "sc" ] = "塞舌尔";
 theUILang.country[ "sd" ] = "苏丹红";
 theUILang.country[ "se" ] = "瑞典";
 theUILang.country[ "sg" ] = "新加坡";
 theUILang.country[ "sh" ] = "圣赫勒拿";
 theUILang.country[ "si" ] = "斯洛文尼亚";
 theUILang.country[ "sj" ] = "斯瓦尔巴群岛和扬马延";
 theUILang.country[ "sk" ] = "斯洛伐克";
 theUILang.country[ "sl" ] = "塞拉利昂";
 theUILang.country[ "sm" ] = "圣马力诺";
 theUILang.country[ "sn" ] = "塞内加尔";
 theUILang.country[ "so" ] = "索马里";
 theUILang.country[ "sr" ] = "苏里南";
 theUILang.country[ "ss" ] = "苏丹南部";
 theUILang.country[ "st" ] = "圣多美和普林西比";
 theUILang.country[ "sv" ] = "萨尔瓦多";
 theUILang.country[ "sx" ] = "圣马丁岛";
 theUILang.country[ "sy" ] = "叙利亚";
 theUILang.country[ "sz" ] = "斯威士兰";
 theUILang.country[ "tc" ] = "特克斯和凯科斯群岛";
 theUILang.country[ "td" ] = "乍得";
 theUILang.country[ "tf" ] = "法国南部领土";
 theUILang.country[ "tg" ] = "多哥";
 theUILang.country[ "th" ] = "泰国";
 theUILang.country[ "tj" ] = "塔吉克斯坦";
 theUILang.country[ "tk" ] = "托克劳";
 theUILang.country[ "tl" ] = "东帝汶";
 theUILang.country[ "tm" ] = "土库曼斯坦";
 theUILang.country[ "tn" ] = "突尼斯";
 theUILang.country[ "to" ] = "汤加";
 theUILang.country[ "tr" ] = "土耳其";
 theUILang.country[ "tt" ] = "特立尼达和多巴哥";
 theUILang.country[ "tv" ] = "图瓦卢";
 theUILang.country[ "tw" ] = "台湾";
 theUILang.country[ "tz" ] = "坦桑尼亚";
 theUILang.country[ "ua" ] = "乌克兰";
 theUILang.country[ "ug" ] = "乌干达";
 theUILang.country[ "um" ] = "美国本土外小岛屿";
 theUILang.country[ "un" ] = "未知";
 theUILang.country[ "us" ] = "美国";
 theUILang.country[ "uy" ] = "乌拉圭";
 theUILang.country[ "uz" ] = "乌兹别克斯坦";
 theUILang.country[ "va" ] = "梵";
 theUILang.country[ "vc" ] = "圣文森特和格林纳丁斯";
 theUILang.country[ "ve" ] = "委内瑞拉";
 theUILang.country[ "vg" ] = "英属维尔京群岛";
 theUILang.country[ "vi" ] = "美属维尔京群岛";
 theUILang.country[ "vn" ] = "越南";
 theUILang.country[ "vu" ] = "瓦努阿图";
 theUILang.country[ "wf" ] = "瓦利斯群岛和富图纳群岛";
 theUILang.country[ "ws" ] = "萨摩亚";
 theUILang.country[ "ye" ] = "也门";
 theUILang.country[ "yt" ] = "马约特";
 theUILang.country[ "za" ] = "南非";
 theUILang.country[ "zm" ] = "赞比亚";
 theUILang.country[ "zw" ] = "津巴布韦";

thePlugins.get("geoip").langLoaded();

==> rutorrent-4.3.5.tar.gz: ruTorrent-4.3.5/plugins/geoip/lang/zh-cn.js <==
﻿/*
 * PLUGIN GEOIP
 *
 * Chinese Simplified language file.
 *
 * Initial Author: art.spb, December 2009.
 *
 * Author: 
 */

 theUILang.peerComment		= "添加注释";
 theUILang.peerCommentLabel	= "为这个 peer 添加新注释";
 theUILang.commentName		= "注释";
 theUILang.countryName		= "国家";

 theUILang.country = new Array();
 theUILang.country[ "ad" ] = "安道尔";
 theUILang.country[ "ae" ] = "阿拉伯联合酋长国";
 theUILang.country[ "af" ] = "阿富汗";
 theUILang.country[ "ag" ] = "安提瓜和巴布达";
 theUILang.country[ "ai" ] = "安圭拉";
 theUILang.country[ "al" ] = "阿尔巴尼亚";
 theUILang.country[ "am" ] = "亚美尼亚";
 theUILang.country[ "ao" ] = "安哥拉";
 theUILang.country[ "aq" ] = "南极";
 theUILang.country[ "ar" ] = "阿根廷";
 theUILang.country[ "as" ] = "美属萨摩亚";
 theUILang.country[ "at" ] = "奥地利";
 theUILang.country[ "au" ] = "澳大利亚";
 theUILang.country[ "aw" ] = "阿鲁巴";
 theUILang.country[ "ax" ] = "奥兰群岛";
 theUILang.country[ "az" ] = "阿塞拜疆";
 theUILang.country[ "ba" ] = "波黑";
 theUILang.country[ "bb" ] = "巴巴多斯";
 theUILang.country[ "bd" ] = "孟加拉国";
 theUILang.country[ "be" ] = "比利时";
 theUILang.country[ "bf" ] = "布基纳法索";
 theUILang.country[ "bg" ] = "保加利亚";
 theUILang.country[ "bh" ] = "巴林";
 theUILang.country[ "bi" ] = "布隆迪";
 theUILang.country[ "bj" ] = "贝宁";
 theUILang.country[ "bl" ] = "圣巴泰勒米";
 theUILang.country[ "bm" ] = "百慕大";
 theUILang.country[ "bn" ] = "文莱";
 theUILang.country[ "bo" ] = "玻利维亚";
 theUILang.country[ "bq" ] = "博奈尔";
 theUILang.country[ "br" ] = "巴西";
 theUILang.country[ "bs" ] = "巴哈马";
 theUILang.country[ "bt" ] = "不丹";
 theUILang.country[ "bv" ] = "布韦岛";
 theUILang.country[ "bw" ] = "博茨瓦纳";
 theUILang.country[ "by" ] = "白俄罗斯";
 theUILang.country[ "bz" ] = "伯利兹";
 theUILang.country[ "ca" ] = "加拿大";
 theUILang.country[ "cc" ] = "科科斯群岛";
 theUILang.country[ "cd" ] = "刚果（金）";
 theUILang.country[ "cf" ] = "中非共和国";
 theUILang.country[ "cg" ] = "刚果（布）";
 theUILang.country[ "ch" ] = "瑞士";
 theUILang.country[ "ci" ] = "科特迪瓦";
 theUILang.country[ "ck" ] = "库克群岛";
 theUILang.country[ "cl" ] = "智利";
 theUILang.country[ "cm" ] = "喀麦隆";
 theUILang.country[ "cn" ] = "中国";
 theUILang.country[ "co" ] = "哥伦比亚";
 theUILang.country[ "cr" ] = "哥斯达黎加";
 theUILang.country[ "cu" ] = "古巴";
 theUILang.country[ "cv" ] = "佛得角";
 theUILang.country[ "cw" ] = "库拉索";
 theUILang.country[ "cx" ] = "圣诞岛";
 theUILang.country[ "cy" ] = "塞浦路斯";
 theUILang.country[ "cz" ] = "捷克共和国";
 theUILang.country[ "de" ] = "德国";
 theUILang.country[ "dj" ] = "吉布提";
 theUILang.country[ "dk" ] = "丹麦";
 theUILang.country[ "dm" ] = "多米尼克";
 theUILang.country[ "do" ] = "多米尼加共和国";
 theUILang.country[ "dz" ] = "阿尔及利亚";
 theUILang.country[ "ec" ] = "厄瓜多尔";
 theUILang.country[ "ee" ] = "爱沙尼亚";
 theUILang.country[ "eg" ] = "埃及";
 theUILang.country[ "eh" ] = "西撒哈拉";
 theUILang.country[ "er" ] = "厄立特里亚";
 theUILang.country[ "es" ] = "西班牙";
 theUILang.country[ "et" ] = "埃塞俄比亚";
 theUILang.country[ "eu" ] = "欧联";
 theUILang.country[ "fi" ] = "芬兰";
 theUILang.country[ "fj" ] = "斐济";
 theUILang.country[ "fk" ] = "福克兰群岛";
 theUILang.country[ "fm" ] = "密克罗尼西亚";
 theUILang.country[ "fo" ] = "法罗群岛";
 theUILang.country[ "fr" ] = "法国";
 theUILang.country[ "ga" ] = "加蓬";
 theUILang.country[ "gb" ] = "英国";
 theUILang.country[ "gd" ] = "格林纳达";
 theUILang.country[ "ge" ] = "格鲁吉亚";
 theUILang.country[ "gf" ] = "法属圭亚那";
 theUILang.country[ "gg" ] = "根西岛";
 theUILang.country[ "gh" ] = "加纳";
 theUILang.country[ "gi" ] = "直布罗陀";
 theUILang.country[ "gl" ] = "格陵兰";
 theUILang.country[ "gm" ] = "冈比亚";
 theUILang.country[ "gn" ] = "几内亚";
 theUILang.country[ "gp" ] = "瓜德罗普";
 theUILang.country[ "gq" ] = "赤道几内亚";
 theUILang.country[ "gr" ] = "希腊";
 theUILang.country[ "gs" ] = "南乔治亚岛和南桑威奇群岛";
 theUILang.country[ "gt" ] = "危地马拉";
 theUILang.country[ "gu" ] = "关岛";
 theUILang.country[ "gw" ] = "几内亚比绍";
 theUILang.country[ "gy" ] = "圭亚那";
 theUILang.country[ "hk" ] = "香港";
 theUILang.country[ "hm" ] = "赫德岛和麦克唐纳群岛";
 theUILang.country[ "hn" ] = "洪都拉斯";
 theUILang.country[ "hr" ] = "克罗地亚";
 theUILang.country[ "ht" ] = "海地";
 theUILang.country[ "hu" ] = "匈牙利";
 theUILang.country[ "id" ] = "印尼";
 theUILang.country[ "ie" ] = "爱尔兰";
 theUILang.country[ "il" ] = "以色列";
 theUILang.country[ "im" ] = "马恩岛";
 theUILang.country[ "in" ] = "印度";
 theUILang.country[ "io" ] = "英属印度洋领地";
 theUILang.country[ "iq" ] = "伊拉克";
 theUILang.country[ "ir" ] = "伊朗";
 theUILang.country[ "is" ] = "冰岛";
 theUILang.country[ "it" ] = "意大利";
 theUILang.country[ "je" ] = "泽西";
 theUILang.country[ "jm" ] = "牙买加";
 theUILang.country[ "jo" ] = "约旦";
 theUILang.country[ "jp" ] = "日本";
 theUILang.country[ "ke" ] = "肯尼亚";
 theUILang.country[ "kg" ] = "吉尔吉斯斯坦";
 theUILang.country[ "kh" ] = "柬埔寨";
 theUILang.country[ "ki" ] = "基里巴斯";
 theUILang.country[ "km" ] = "科摩罗";
 theUILang.country[ "kn" ] = "圣基茨和尼维斯";
 theUILang.country[ "kp" ] = "朝鲜";
 theUILang.country[ "kr" ] = "韩国";
 theUILang.country[ "kw" ] = "科威特";
 theUILang.country[ "ky" ] = "开曼群岛";
 theUILang.country[ "kz" ] = "哈萨克斯坦";
 theUILang.country[ "la" ] = "老挝";
 theUILang.country[ "lb" ] = "黎巴嫩";
 theUILang.country[ "lc" ] = "圣卢西亚";
 theUILang.country[ "li" ] = "列支敦士登";
 theUILang.country[ "lk" ] = "斯里兰卡";
 theUILang.country[ "lr" ] = "利比里亚";
 theUILang.country[ "ls" ] = "莱索托";
 theUILang.country[ "lt" ] = "立陶宛";
 theUILang.country[ "lu" ] = "卢森堡";
 theUILang.country[ "lv" ] = "拉脱维亚";
 theUILang.country[ "ly" ] = "利比亚";
 theUILang.country[ "ma" ] = "摩洛哥";
 theUILang.country[ "mc" ] = "摩纳哥";
 theUILang.country[ "md" ] = "摩尔多瓦";
 theUILang.country[ "me" ] = "黑山";
 theUILang.country[ "mf" ] = "圣马丁";
 theUILang.country[ "mg" ] = "马达加斯加";
 theUILang.country[ "mh" ] = "马绍尔群岛";
 theUILang.country[ "mk" ] = "北马其顿";
 theUILang.country[ "ml" ] = "马里";
 theUILang.country[ "mm" ] = "缅甸";
 theUILang.country[ "mn" ] = "蒙古";
 theUILang.country[ "mo" ] = "澳门";
 theUILang.country[ "mp" ] = "北马里亚纳群岛";
 theUILang.country[ "mq" ] = "马提尼克岛";
 theUILang.country[ "mr" ] = "毛里塔尼亚";
 theUILang.country[ "ms" ] = "蒙特塞拉特";
 theUILang.country[ "mt" ] = "马耳他";
 theUILang.country[ "mu" ] = "毛里求斯";
 theUILang.country[ "mv" ] = "马尔代夫";
 theUILang.country[ "mw" ] = "马拉维";
 theUILang.country[ "mx" ] = "墨西哥";
 theUILang.country[ "my" ] = "马来西亚";
 theUILang.country[ "mz" ] = "莫桑比克";
 theUILang.country[ "na" ] = "纳米比亚";
 theUILang.country[ "nc" ] = "新喀里多尼亚";
 theUILang.country[ "ne" ] = "尼日尔";
 theUILang.country[ "nf" ] = "诺福克岛";
 theUILang.country[ "ng" ] = "尼日利亚";
 theUILang.country[ "ni" ] = "尼加拉瓜";
 theUILang.country[ "nl" ] = "荷兰";
 theUILang.country[ "no" ] = "挪威";
 theUILang.country[ "np" ] = "尼泊尔";
 theUILang.country[ "nr" ] = "瑙鲁";
 theUILang.country[ "nu" ] = "纽埃";
 theUILang.country[ "nz" ] = "新西兰";
 theUILang.country[ "om" ] = "阿曼";
 theUILang.country[ "pa" ] = "巴拿马";
 theUILang.country[ "pe" ] = "秘鲁";
 theUILang.country[ "pf" ] = "法属波利尼西亚";
 theUILang.country[ "pg" ] = "巴布亚新几内亚";
 theUILang.country[ "ph" ] = "菲律宾";
 theUILang.country[ "pk" ] = "巴基斯坦";
 theUILang.country[ "pl" ] = "波兰";
 theUILang.country[ "pm" ] = "圣皮埃尔和密克隆";
 theUILang.country[ "pn" ] = "皮特凯恩群岛";
 theUILang.country[ "pr" ] = "波多黎各";
 theUILang.country[ "ps" ] = "巴勒斯坦";
 theUILang.country[ "pt" ] = "葡萄牙";
 theUILang.country[ "pw" ] = "帕劳";
 theUILang.country[ "py" ] = "巴拉圭";
 theUILang.country[ "qa" ] = "卡塔尔";
 theUILang.country[ "re" ] = "留尼汪";
 theUILang.country[ "ro" ] = "罗马尼亚";
 theUILang.country[ "rs" ] = "塞尔维亚";
 theUILang.country[ "ru" ] = "俄罗斯";
 theUILang.country[ "rw" ] = "卢旺达";
 theUILang.country[ "sa" ] = "沙特阿拉伯";
 theUILang.country[ "sb" ] = "所罗门群岛";
 theUILang.country[ "sc" ] = "塞舌尔";
 theUILang.country[ "sd" ] = "苏丹";
 theUILang.country[ "se" ] = "瑞典";
 theUILang.country[ "sg" ] = "新加坡";
 theUILang.country[ "sh" ] = "圣赫勒拿";
 theUILang.country[ "si" ] = "斯洛文尼亚";
 theUILang.country[ "sj" ] = "斯瓦尔巴和扬马延";
 theUILang.country[ "sk" ] = "斯洛伐克";
 theUILang.country[ "sl" ] = "塞拉利昂";
 theUILang.country[ "sm" ] = "圣马力诺";
 theUILang.country[ "sn" ] = "塞内加尔";
 theUILang.country[ "so" ] = "索马里";
 theUILang.country[ "sr" ] = "苏里南";
 theUILang.country[ "ss" ] = "南苏丹";
 theUILang.country[ "st" ] = "圣多美和普林西比";
 theUILang.country[ "sv" ] = "萨尔瓦多";
 theUILang.country[ "sx" ] = "圣马丁岛";
 theUILang.country[ "sy" ] = "叙利亚";
 theUILang.country[ "sz" ] = "斯威士兰";
 theUILang.country[ "tc" ] = "特克斯和凯科斯群岛";
 theUILang.country[ "td" ] = "乍得";
 theUILang.country[ "tf" ] = "法属南部领地";
 theUILang.country[ "tg" ] = "多哥";
 theUILang.country[ "th" ] = "泰国";
 theUILang.country[ "tj" ] = "塔吉克斯坦";
 theUILang.country[ "tk" ] = "托克劳";
 theUILang.country[ "tl" ] = "东帝汶";
 theUILang.country[ "tm" ] = "土库曼斯坦";
 theUILang.country[ "tn" ] = "突尼斯";
 theUILang.country[ "to" ] = "汤加";
 theUILang.country[ "tr" ] = "土耳其";
 theUILang.country[ "tt" ] = "特立尼达和多巴哥";
 theUILang.country[ "tv" ] = "图瓦卢";
 theUILang.country[ "tw" ] = "台湾";
 theUILang.country[ "tz" ] = "坦桑尼亚";
 theUILang.country[ "ua" ] = "乌克兰";
 theUILang.country[ "ug" ] = "乌干达";
 theUILang.country[ "um" ] = "美属外部小群岛";
 theUILang.country[ "un" ] = "未知";
 theUILang.country[ "us" ] = "美国";
 theUILang.country[ "uy" ] = "乌拉圭";
 theUILang.country[ "uz" ] = "乌兹别克斯坦";
 theUILang.country[ "va" ] = "梵蒂冈";
 theUILang.country[ "vc" ] = "圣文森特和格林纳丁斯";
 theUILang.country[ "ve" ] = "委内瑞拉";
 theUILang.country[ "vg" ] = "英属维尔京群岛";
 theUILang.country[ "vi" ] = "美属维尔京群岛";
 theUILang.country[ "vn" ] = "越南";
 theUILang.country[ "vu" ] = "瓦努阿图";
 theUILang.country[ "wf" ] = "瓦利斯群岛和富图纳群岛";
 theUILang.country[ "ws" ] = "萨摩亚";
 theUILang.country[ "ye" ] = "也门";
 theUILang.country[ "yt" ] = "马约特";
 theUILang.country[ "za" ] = "南非";
 theUILang.country[ "zm" ] = "赞比亚";
 theUILang.country[ "zw" ] = "津巴布韦";

thePlugins.get("geoip").langLoaded();
